apply_smoothing_and_coord_transform — pysm v3.1.dev260

pysm:docs

- Index
- Modules

### Navigation

- next »
- « previous |
- pysm v3.1.dev260 »
- apply_smoothing_and_coord_transform

# apply_smoothing_and_coord_transform

`pysm.` `apply_smoothing_and_coord_transform`(input_map, fwhm=None, rot=None, lmax=None, map_dist=None)

  Apply smoothing and coordinate rotation to an input map

  it applies the `healpy.smoothing` Gaussian smoothing kernel if `map_dist` is None, otherwise applies distributed smoothing with `libsharp`. In the distributed case, no rotation is supported.

  Parameters
    input_mapndarray

      Input map, of shape `(3, npix)` This is assumed to have no beam at this point, as the simulated small scale tempatle on which the simulations are based have no beam.

    fwhmastropy.units.Quantity

      Full width at half-maximum, defining the Gaussian kernels to be applied.

    rot: hp.Rotator

      Apply a coordinate rotation give a healpy `Rotator`, e.g. if the inputs are in Galactic, `hp.Rotator(coord=("G", "C"))` rotates to Equatorial

  Returns
    smoothed_mapnp.ndarray

      Array containing the smoothed sky